package org.springframework.boot.loader.jar;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import java.io.IOException;
import java.net.MalformedURLException;
import java.net.URL;
import java.security.CodeSigner;
import java.security.cert.Certificate;
import java.util.jar.Attributes;
import java.util.jar.JarEntry;
import java.util.jar.Manifest;
import org.springframework.boot.loader.jar.AsciiBytes;
import org.springframework.boot.loader.jar.CentralDirectoryFileHeader;
import org.springframework.boot.loader.jar.FileHeader;
import org.springframework.boot.loader.jar.JarEntryCertification;
import org.springframework.boot.loader.jar.JarFile;

class JarEntry extends JarEntry implements FileHeader {
  private final int index;
  
  private final AsciiBytes name;
  
  private final AsciiBytes headerName;
  
  private final JarFile jarFile;
  
  private long localHeaderOffset;
  
  private volatile JarEntryCertification certification;
  
  JarEntry(JarFile jarFile, int index, CentralDirectoryFileHeader header, AsciiBytes nameAlias) {
    super((nameAlias != null) ? nameAlias.toString() : header.getName().toString());
    this.index = index;
    this.name = (nameAlias != null) ? nameAlias : header.getName();
    this.headerName = header.getName();
    this.jarFile = jarFile;
    this.localHeaderOffset = header.getLocalHeaderOffset();
    setCompressedSize(header.getCompressedSize());
    setMethod(header.getMethod());
    setCrc(header.getCrc());
    setComment(header.getComment().toString());
    setSize(header.getSize());
    setTime(header.getTime());
    if (header.hasExtra())
      setExtra(header.getExtra()); 
  }
  
  int getIndex() {
    return this.index;
  }
  
  AsciiBytes getAsciiBytesName() {
    return this.name;
  }
  
  public boolean hasName(CharSequence name, char suffix) {
    return this.headerName.matches(name, suffix);
  }
  
  URL getUrl() throws MalformedURLException {
    return new URL(this.jarFile.getUrl(), getName());
  }
  
  public Attributes getAttributes() throws IOException {
    Manifest manifest = this.jarFile.getManifest();
    return (manifest != null) ? manifest.getAttributes(getName()) : null;
  }
  
  public Certificate[] getCertificates() {
    return getCertification().getCertificates();
  }
  
  public CodeSigner[] getCodeSigners() {
    return getCertification().getCodeSigners();
  }
  
  private JarEntryCertification getCertification() {
    if (!this.jarFile.isSigned())
      return JarEntryCertification.NONE; 
    JarEntryCertification certification = this.certification;
    if (certification == null) {
      certification = this.jarFile.getCertification(this);
      this.certification = certification;
    } 
    return certification;
  }
  
  public long getLocalHeaderOffset() {
    return this.localHeaderOffset;
  }
}
